
Unnecessary features enabled or installed
-------

**Description:**

Whenever there are unnecessary features enabled or installed this could increase
the attack vector which could lead to serious danger such as XXE/CMD/XSS injections.


**Solution:**

Make sure al features and software available on the application/server is necessary for 
application to work proper. if not, uninstall or disable these services.

	
